@@ -47,7 +47,7 @@ EPublisher::Source::Base - Base class for Source plugins
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -80,17 +80,6 @@ of hashreferences where each reference should look like
       title    => $a_title_for_documentation,
   }
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2010 - 2012 Renee Baecker, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms of Artistic License 2.0.
-
-=head1 AUTHOR
-
-Renee Baecker (E<lt>module@renee-baecker.deE<gt>)
-
 =head1 AUTHOR
 
 Renee Baecker <module@renee-baecker.de>
